@@ -45,11 +45,15 @@
 #include "mark_played_cmd.h"
 #include "ai_player.h"
 #include "settings.h"
+#include "encoding.h"
 #include "debug.h"
 
 
-Duplicate::Duplicate(const Dictionary &iDic)
-    : Game(iDic)
+INIT_LOGGER(game, Duplicate);
+
+
+Duplicate::Duplicate(const GameParams &iParams)
+    : Game(iParams)
 {
 }
 
@@ -147,6 +151,12 @@ void Duplicate::start()
 }
 
 
+bool Duplicate::isFinished() const
+{
+    return m_finished;
+}
+
+
 void Duplicate::tryEndTurn()
 {
     for (unsigned int i = 0; i < getNPlayers(); i++)
@@ -177,6 +187,7 @@ void Duplicate::tryEndTurn()
 
 void Duplicate::recordPlayerMove(const Move &iMove, Player &ioPlayer, bool isForHuman)
 {
+    LOG_INFO("Player " << ioPlayer.getId() << " plays: " << lfw(iMove.toString()));
     Command *pCmd = new PlayerMoveCmd(ioPlayer, iMove);
     pCmd->setAutoExecution(!isForHuman);
     accessNavigation().addAndExecute(pCmd);
@@ -278,6 +289,7 @@ void Duplicate::endTurn()
 
 void Duplicate::endGame()
 {
+    LOG_INFO("End of the game");
     m_finished = true;
 }
 
