@@ -23,6 +23,7 @@
 
 #include "game.h"
 #include "command.h"
+#include "logging.h"
 
 class Player;
 
@@ -53,11 +54,10 @@ using std::wstring;
  */
 class Duplicate: public Game
 {
+    DEFINE_LOGGER();
     friend class GameFactory;
     friend class MarkPlayedCmd;
 public:
-    virtual GameMode getMode() const { return kDUPLICATE; }
-    virtual string getModeAsString() const { return "Duplicate"; }
 
     /*************************
      * Game handling
@@ -71,6 +71,8 @@ public:
      */
     virtual void start();
 
+    virtual bool isFinished() const;
+
     /**
      * See description of Game::play() for the possible return values.
      * Note that if the "duplicate-reject-invalid" setting is set to false
@@ -93,7 +95,7 @@ public:
 
 private:
     // Private constructor to force using the GameFactory class
-    Duplicate(const Dictionary &iDic);
+    Duplicate(const GameParams &iParams);
 
     /// Record a player move
     void recordPlayerMove(const Move &iMove, Player &ioPlayer, bool isForHuman);
