@@ -22,6 +22,7 @@
 #define FREEGAME_H_
 
 #include "game.h"
+#include "logging.h"
 
 class Player;
 
@@ -42,10 +43,9 @@ using std::vector;
  */
 class FreeGame: public Game
 {
+    DEFINE_LOGGER();
     friend class GameFactory;
 public:
-    virtual GameMode getMode() const { return kFREEGAME; }
-    virtual string getModeAsString() const { return "Free game"; }
 
     /*************************
      * Game handling
@@ -55,6 +55,8 @@ public:
      */
     virtual void start();
 
+    virtual bool isFinished() const;
+
     /**
      * See description of Game::play() for the possible return values.
      * Note that if the "freegame-reject-invalid" setting is set to false
@@ -80,7 +82,7 @@ public:
 
 private:
     // Private constructor to force using the GameFactory class
-    FreeGame(const Dictionary &iDic);
+    FreeGame(const GameParams &iParams);
 
     /// Make the AI player whose ID is p play its turn
     void playAI(unsigned int p);
