@@ -46,13 +46,12 @@
 
 #include "debug.h"
 
-const unsigned int Game::RACK_SIZE =  7;
-const int Game::BONUS_POINTS = 50;
+INIT_LOGGER(game, Game);
 
-Game::Game(const Dictionary &iDic):
-    m_dic(iDic), m_bag(iDic)
+
+Game::Game(const GameParams &iParams):
+    m_params(iParams), m_board(m_params), m_bag(iParams.getDic())
 {
-    m_variant = kNONE;
     m_points = 0;
     m_currPlayer = 0;
     m_finished = false;
@@ -77,6 +76,7 @@ const Player& Game::getPlayer(unsigned int iNum) const
 
 void Game::shuffleRack()
 {
+    LOG_DEBUG("Shuffling rack for player " << currPlayer());
     PlayedRack pld = getCurrentPlayer().getCurrentRack();
     pld.shuffle();
     m_players[currPlayer()]->setCurrentRack(pld);
@@ -91,7 +91,7 @@ void Game::realBag(Bag &ioBag) const
     vector<Tile> tiles;
 
     // The real content of the bag depends on the game mode
-    if (getMode() == kFREEGAME)
+    if (getMode() == GameParams::kFREEGAME)
     {
         // In freegame mode, take the letters from all the racks
         BOOST_FOREACH(const Player *player, m_players)
@@ -141,7 +141,7 @@ PlayedRack Game::helperSetRackRandom(const PlayedRack &iPld,
     // Create a copy of the bag in which we can do everything we want,
     // and take from it the tiles of the players rack so that "bag"
     // contains the right number of tiles.
-    Bag bag(m_dic);
+    Bag bag(getDic());
     realBag(bag);
     if (mode == RACK_NEW && nold != 0)
     {
@@ -174,6 +174,8 @@ PlayedRack Game::helperSetRackRandom(const PlayedRack &iPld,
         throw GameException(_("Not a random mode"));
     }
 
+    const unsigned int RACK_SIZE = m_params.getRackSize();
+
     // Get the tiles remaining on the rack
     vector<Tile> tiles;
     pld.getOldTiles(tiles);
@@ -184,7 +186,8 @@ PlayedRack Game::helperSetRackRandom(const PlayedRack &iPld,
 
     bool jokerAdded = false;
     // Are we dealing with a normal game or a joker game?
-    if (m_variant == kJOKER || m_variant == kEXPLOSIVE)
+    if (m_params.hasVariant(GameParams::kJOKER) ||
+        m_params.hasVariant(GameParams::kEXPLOSIVE))
     {
         // 1) Is there already a joker in the remaining letters of the rack?
         bool jokerFound = false;
@@ -327,7 +330,7 @@ PlayedRack Game::helperSetRackRandom(const PlayedRack &iPld,
     // In explosive games, we have to perform a search, then replace the
     // joker with the letter providing the best score
     // A joker coming from a previous rack is not replaced
-    if (m_variant == kEXPLOSIVE && jokerAdded)
+    if (m_params.hasVariant(GameParams::kEXPLOSIVE) && jokerAdded)
     {
         Rack rack;
         pld.getRack(rack);
@@ -340,11 +343,10 @@ PlayedRack Game::helperSetRackRandom(const PlayedRack &iPld,
 
             // Get the best word
             const Round & bestRound = res.get(0);
-#ifdef DEBUG
-                    cout << "helperSetRackRandom(): initial rack: "
-                         << convertToMb(pld.toString()) << " (best word: "
-                         << convertToMb(bestRound.getWord()) << ")" << endl;
-#endif
+            LOG_DEBUG("helperSetRackRandom(): initial rack: "
+                      << lfw(pld.toString()) << " (best word: "
+                      << lfw(bestRound.getWord()) << ")");
+
             // Identify the joker
             for (unsigned int i = 0; i < bestRound.getWordLen(); ++i)
             {
@@ -352,10 +354,9 @@ PlayedRack Game::helperSetRackRandom(const PlayedRack &iPld,
                 {
                     const Tile &jokerTile = bestRound.getTile(i);
                     Tile replacingTile(towupper(jokerTile.toChar()));
-#ifdef DEBUG
-                    cout << "helperSetRackRandom(): replacing Joker with "
-                         << convertToMb(replacingTile.toChar()) << endl;
-#endif
+                    LOG_DEBUG("helperSetRackRandom(): replacing Joker with "
+                              << lfw(replacingTile.toChar()));
+
                     // If the bag does not contain this letter anymore,
                     // simply keep the joker in the rack.
                     if (bag.in(replacingTile))
@@ -395,7 +396,7 @@ PlayedRack Game::helperSetRackRandom(const PlayedRack &iPld,
 
 bool Game::rackInBag(const Rack &iRack, const Bag &iBag) const
 {
-    BOOST_FOREACH(const Tile &t, m_dic.getAllTiles())
+    BOOST_FOREACH(const Tile &t, getDic().getAllTiles())
     {
         if (iRack.in(t) > iBag.in(t))
             return false;
@@ -406,7 +407,7 @@ bool Game::rackInBag(const Rack &iRack, const Bag &iBag) const
 
 PlayedRack Game::helperSetRackManual(bool iCheck, const wstring &iLetters) const
 {
-    if (!m_dic.validateLetters(iLetters, L"+-"))
+    if (!getDic().validateLetters(iLetters, L"+-"))
         throw GameException(_("Some letters are invalid for the current dictionary"));
 
     PlayedRack pld;
@@ -457,6 +458,10 @@ void Game::addPlayer(Player *iPlayer)
     // The ID of the player is its position in the m_players vector
     iPlayer->setId(getNPlayers());
     m_players.push_back(iPlayer);
+
+    LOG_INFO("Adding player '" << lfw(iPlayer->getName())
+             << "' (" << (iPlayer->isHuman() ? "human" : "AI") << ")"
+             << " with ID " << iPlayer->getId());
 }
 
 
@@ -506,7 +511,7 @@ int Game::checkPlayedWord(const wstring &iCoord,
 {
     ASSERT(getNPlayers() != 0, "Expected at least one player");
 
-    if (!m_dic.validateLetters(iWord))
+    if (!getDic().validateLetters(iWord))
         return 1;
 
     // Init the round with the given coordinates
@@ -518,7 +523,7 @@ int Game::checkPlayedWord(const wstring &iCoord,
     }
 
     // Check the existence of the word
-    if (!m_dic.searchWord(iWord))
+    if (!getDic().searchWord(iWord))
     {
         return 3;
     }
@@ -545,7 +550,7 @@ int Game::checkPlayedWord(const wstring &iCoord,
     if (res != 0)
         return res + 4;
     // In duplicate mode, the first word must be horizontal
-    if (getMode() == kDUPLICATE && m_board.isVacant(8, 8))
+    if (getMode() == GameParams::kDUPLICATE && m_board.isVacant(8, 8))
     {
         if (oRound.getCoord().getDir() == Coord::VERTICAL)
             return 10;
