@@ -24,7 +24,8 @@
 
 #include <string>
 #include <vector>
-#include <iostream>
+#include "game_params.h"
+#include "logging.h"
 #include "bag.h"
 #include "board.h"
 #include "history.h"
@@ -48,55 +49,30 @@ using namespace std;
  */
 class Game
 {
+    DEFINE_LOGGER();
 public:
-    /// Game specs.
-    static const unsigned int RACK_SIZE;
-    static const int BONUS_POINTS;
-
-
-    Game(const Dictionary &iDic);
+    Game(const GameParams &iParams);
     virtual ~Game();
 
     /***************
      * Game type
      ***************/
 
-    /// Game mode: each one of these modes is implemented in an inherited class
-    enum GameMode
-    {
-        kTRAINING,
-        kFREEGAME,
-        kDUPLICATE
-    };
-    virtual GameMode getMode() const = 0;
-    virtual string getModeAsString() const = 0;
-
-    /// Game variant: it slightly modifies the rules of the game
-    enum GameVariant
-    {
-        kNONE,      // Normal game rules
-        kJOKER,     // Joker game
-        kEXPLOSIVE  // "Explosive" game
-    };
-
-    /**
-     * Accessors for the variant of the game.
-     * The variant can be changed during a game without any problem
-     * (though it seems rather useless...)
-     */
-    void setVariant(GameVariant iVariant)   { m_variant = iVariant; }
-    GameVariant getVariant() const          { return m_variant; }
+    GameParams::GameMode getMode() const { return m_params.getMode(); }
 
     /***************
      * Various getters
      ***************/
 
+    /// Get the game characteristics
+    const GameParams & getParams() const { return m_params; }
+
     /**
      * Get the dictionary associated with the game.
      * You should never create a new dictionary object while a Game
      * object still exists
      */
-    const Dictionary & getDic() const { return m_dic; }
+    const Dictionary & getDic() const { return m_params.getDic(); }
 
     /// Get the board
     const Board& getBoard() const { return m_board; }
@@ -146,6 +122,13 @@ public:
      */
     virtual void start() = 0;
 
+    /**
+     * Indicate whether we reached the end of the game.
+     * This should be checked regularly.
+     * XXX: using a signal would be nice here...
+     */
+    virtual bool isFinished() const = 0;
+
     /**
      * Method used by human players to play the word iWord at coordinates
      * iCoord, and end the turn (if possible)
@@ -163,6 +146,7 @@ public:
      * 10: first word not horizontal (can only happen in duplicate mode)
      * 11: first word not covering the H8 square
      * 12: word going out of the board
+     * 13: too many letters played from the rack
      */
     virtual int play(const wstring &iCoord, const wstring &iWord) = 0;
 
@@ -211,11 +195,8 @@ public:
                         bool checkRack = true) const;
 
 private:
-    /// Variant
-    GameVariant m_variant;
-
-    /// Dictionary currently associated to the game
-    const Dictionary & m_dic;
+    /// Game characteristics
+    GameParams m_params;
 
     /**
      * History of the game.
