@@ -21,6 +21,7 @@
 
 #include <cstring>
 #include <cstdlib> // For atoi
+#include <cwctype> // For iswlower
 #include <cstdio>
 
 #include "dic.h"
@@ -29,6 +30,7 @@
 #include "turn.h"
 #include "player.h"
 #include "ai_percent.h"
+#include "game_params.h"
 #include "game.h"
 #include "game_factory.h"
 #include "training.h"
@@ -106,7 +108,7 @@ Game* Game::gameLoadFormat_14(FILE *fin, const Dictionary& iDic)
     char *token;
     Game *pGame = NULL;
 
-    pGame = GameFactory::Instance()->createTraining(iDic);
+    pGame = GameFactory::Instance()->createGame(GameParams(iDic, GameParams::kTRAINING));
     pGame->addPlayer(new HumanPlayer);
     pGame->start();
 
@@ -127,7 +129,7 @@ Game* Game::gameLoadFormat_14(FILE *fin, const Dictionary& iDic)
 
             /* rack */
             strncpy(rack, token, sizeof(rack));
-            static_cast<Training*>(pGame)->setRackManual(false, convertToWc(rack));
+            static_cast<Training*>(pGame)->setRackManual(false, wfl(rack));
 
             /* word */
             token = strtok(NULL, delim);
@@ -163,7 +165,7 @@ Game* Game::gameLoadFormat_14(FILE *fin, const Dictionary& iDic)
             //debug("%s)", token);
             strncat(pos, token, sizeof(pos) - strlen(pos) - 1);
 
-            if ((ret = pGame->play(convertToWc(pos), convertToWc(word))))
+            if ((ret = pGame->play(wfl(pos), wfl(word))))
             {
                 GameFactory::Instance()->releaseGame(*pGame);
                 char tmp1[10];
@@ -203,25 +205,17 @@ Game* Game::gameLoadFormat_15(FILE *fin, const Dictionary& iDic)
                 return NULL;
             }
             // Create the correct Game object
+            GameParams::GameMode mode;
             if (strstr(buff, "Training"))
-            {
-                pGame = GameFactory::Instance()->createTraining(iDic);
-                break;
-            }
+                mode = GameParams::kTRAINING;
             else if (strstr(buff, "Free game"))
-            {
-                pGame = GameFactory::Instance()->createFreeGame(iDic);
-                break;
-            }
+                mode = GameParams::kFREEGAME;
             else if (strstr(buff, "Duplicate"))
-            {
-                pGame = GameFactory::Instance()->createDuplicate(iDic);
-                break;
-            }
+                mode = GameParams::kDUPLICATE;
             else
-            {
                 throw GameException("Unknown game type");
-            }
+
+            pGame = GameFactory::Instance()->createGame(GameParams(iDic, mode));
         }
     }
 
@@ -245,7 +239,7 @@ Game* Game::gameLoadFormat_15(FILE *fin, const Dictionary& iDic)
                 }
                 else if (string(type) == "Computer")
                 {
-                    if (pGame->getMode() == kTRAINING)
+                    if (pGame->getMode() == GameParams::kTRAINING)
                     {
                         break;
                     }
@@ -326,11 +320,11 @@ Game* Game::gameLoadFormat_15(FILE *fin, const Dictionary& iDic)
 
         // Build a rack for the correct player
         PlayedRack pldrack;
-        if (!iDic.validateLetters(convertToWc(rack)))
+        if (!iDic.validateLetters(wfl(rack)))
         {
             throw GameException("Rack invalid for the current dictionary");
         }
-        pldrack.setManual(convertToWc(rack));
+        pldrack.setManual(wfl(rack));
 
         // Build a round
         Round round;
@@ -338,7 +332,7 @@ Game* Game::gameLoadFormat_15(FILE *fin, const Dictionary& iDic)
         if (bonus == '*')
             round.setBonus(1);
 
-        wstring word = convertToWc(tmpWord);
+        wstring word = wfl(tmpWord);
         Tile tile;
         if (isalpha(ref[0]))
         {
@@ -410,7 +404,7 @@ Game* Game::gameLoadFormat_15(FILE *fin, const Dictionary& iDic)
         {
             // Create the played rack
             PlayedRack pldrack;
-            pldrack.setManual(convertToWc(letters));
+            pldrack.setManual(wfl(letters));
             // Give the rack to the player
             pGame->m_players[nb]->setCurrentRack(pldrack);
         }
