@@ -22,13 +22,16 @@
 
 #include "game_move_cmd.h"
 #include "player.h"
+#include "game_params.h"
 #include "game.h"
 #include "rack.h"
+#include "turn.h"
 
 
 GameMoveCmd::GameMoveCmd(Game &ioGame, const Move &iMove,
-                         const PlayedRack &iMoveRack, unsigned int iPlayerId)
-    : m_game(ioGame), m_move(iMove), m_moveRack(iMoveRack),
+                         unsigned int iPlayerId)
+    : m_game(ioGame), m_move(iMove),
+    m_moveRack(ioGame.getPlayer(iPlayerId).getHistory().getPreviousTurn().getPlayedRack()),
     m_playerId(iPlayerId)
 {
 }
@@ -100,7 +103,7 @@ void GameMoveCmd::playRound()
         }
     }
 
-    if (m_game.getVariant() == Game::kJOKER)
+    if (m_game.getParams().hasVariant(GameParams::kJOKER))
     {
         for (unsigned int i = 0; i < m_round.getWordLen(); i++)
         {
