@@ -19,6 +19,7 @@
  *****************************************************************************/
 
 #include "public_game.h"
+#include "game_params.h"
 #include "game.h"
 #include "training.h"
 #include "duplicate.h"
@@ -51,31 +52,9 @@ PublicGame::GameMode PublicGame::getMode() const
 }
 
 
-string PublicGame::getModeAsString() const
+const GameParams & PublicGame::getParams() const
 {
-    return m_game.getModeAsString();
-}
-
-
-void PublicGame::setVariant(GameVariant iVariant)
-{
-    if (iVariant == kJOKER)
-        m_game.setVariant(Game::kJOKER);
-    else if (iVariant == kEXPLOSIVE)
-        m_game.setVariant(Game::kEXPLOSIVE);
-    else
-        m_game.setVariant(Game::kNONE);
-}
-
-
-PublicGame::GameVariant PublicGame::getVariant() const
-{
-    if (m_game.getVariant() == Game::kJOKER)
-        return kJOKER;
-    else if (m_game.getVariant() == Game::kEXPLOSIVE)
-        return kEXPLOSIVE;
-    else
-        return kNONE;
+    return m_game.getParams();
 }
 
 
@@ -144,12 +123,28 @@ void PublicGame::start()
 }
 
 
+bool PublicGame::isFinished() const
+{
+    return m_game.isFinished();
+}
+
+
 int PublicGame::play(const wstring &iWord, const wstring &iCoord)
 {
     return m_game.play(iCoord, iWord);
 }
 
 
+int PublicGame::computePoints(const wstring &iWord, const wstring &iCoord) const
+{
+    Round round;
+    int res = m_game.checkPlayedWord(iCoord, iWord, round);
+    if (res > 0)
+        return -res;
+    return round.getPoints();
+}
+
+
 void PublicGame::shuffleRack()
 {
     m_game.shuffleRack();
