@@ -23,6 +23,7 @@
 
 #include <string>
 
+class GameParams;
 class Game;
 class Dictionary;
 class Bag;
@@ -67,28 +68,14 @@ public:
         kDUPLICATE
     };
     GameMode getMode() const;
-    string getModeAsString() const;
-
-    /// Game variant: it slightly modifies the rules of the game
-    enum GameVariant
-    {
-        kNONE,      // Normal game rules
-        kJOKER,     // Joker game
-        kEXPLOSIVE  // "Explosive" game
-    };
-
-    /**
-     * Accessors for the variant of the game.
-     * The variant can be changed during a game without any problem
-     * (though it seems rather useless...)
-     */
-    void setVariant(GameVariant iVariant);
-    GameVariant getVariant() const;
 
     /***************
      * Various getters
      ***************/
 
+    /// Get the game characteristics
+    const GameParams & getParams() const;
+
     /**
      * Get the dictionary associated with the game.
      * You should never create a new dictionary object while a Game
@@ -134,6 +121,13 @@ public:
      */
     void start();
 
+    /**
+     * Indicate whether we reached the end of the game.
+     * This should be checked regularly.
+     * XXX: using a signal would be nice here...
+     */
+    bool isFinished() const;
+
     /**
      * Method used by human players to play the word iWord at coordinates
      * iCoord, and end the turn (if possible)
@@ -154,6 +148,13 @@ public:
      */
     int play(const wstring &iWord, const wstring &iCoord);
 
+    /**
+     * Compute the points for playing the word iWord at coordinates iCoord.
+     * A negative return value indicates an error (same codes as for the
+     * play() method, but negative instead of positive).
+     */
+    int computePoints(const wstring &iWord, const wstring &iCoord) const;
+
     /**
      * Go back to turn iTurn.
      * We must have: iTurn < getHistory().getSize()
