@@ -20,6 +20,7 @@
  *****************************************************************************/
 
 #include <algorithm>
+#include <cwctype> // For towupper
 
 #if ENABLE_NLS
 #   include <libintl.h>
@@ -45,8 +46,11 @@
 #include "debug.h"
 
 
-Training::Training(const Dictionary &iDic)
-    : Game(iDic), m_results(1000)
+INIT_LOGGER(game, Training);
+
+
+Training::Training(const GameParams &iParams)
+    : Game(iParams), m_results(1000)
 {
 }
 
@@ -105,6 +109,7 @@ int Training::play(const wstring &iCoord, const wstring &iWord)
 
 void Training::recordPlayerMove(const Move &iMove, Player &ioPlayer)
 {
+    LOG_INFO("Player " << ioPlayer.getId() << " plays: " << lfw(iMove.toString()));
     // Update the rack and the score of the current player
     // PlayerMoveCmd::execute() must be called before Game::helperPlayMove()
     // (called in this class in endTurn()).
@@ -126,6 +131,14 @@ void Training::start()
 }
 
 
+bool Training::isFinished() const
+{
+    // The game is finished when there is no more tile
+    // (in the bag or in the racks)
+    return getBag().getNbTiles() == 0;
+}
+
+
 void Training::endTurn()
 {
     m_results.clear();
@@ -170,7 +183,7 @@ void Training::addPlayer(Player *iPlayer)
     ASSERT(getNPlayers() == 0,
            "Only one player can be added in Training mode");
     // Force the name of the player
-    iPlayer->setName(convertToWc(_("Training")));
+    iPlayer->setName(wfl(_("Training")));
     Game::addPlayer(iPlayer);
 }
 
