@@ -25,6 +25,7 @@
 #include "xml_reader.h"
 #include "dic.h"
 #include "game_exception.h"
+#include "game_params.h"
 #include "game_factory.h"
 #include "training.h"
 #include "duplicate.h"
@@ -40,12 +41,17 @@
 
 using namespace std;
 
+INIT_LOGGER(game, XmlReader);
+
 
 Game * XmlReader::read(const string &iFileName, const Dictionary &iDic)
 {
     // Try to load the old format first
+    LOG_INFO("Parsing savegame '" << iFileName << "'");
+
     try
     {
+        LOG_DEBUG("Trying old format");
         FILE *fin = fopen(iFileName.c_str(), "r");
         if (fin != NULL)
         {
@@ -53,14 +59,20 @@ Game * XmlReader::read(const string &iFileName, const Dictionary &iDic)
             fclose(fin);
 
             if (game != NULL)
+            {
+                LOG_INFO("Savegame parsed successfully");
                 return game;
+            }
         }
     }
     catch (const GameException &e)
     {
         // Ignore the exception
+        LOG_DEBUG("This doesn't look like the old format");
     }
 
+    LOG_DEBUG("Trying XML format");
+
     ifstream is(iFileName.c_str());
     if (!is.is_open())
         throw LoadGameException("Cannot open file '" + iFileName + "'");
@@ -79,13 +91,15 @@ Game * XmlReader::read(const string &iFileName, const Dictionary &iDic)
     Game *game = handler.getGame();
     if (game == NULL)
         throw LoadGameException(handler.errorMessage);
+
+    LOG_INFO("Savegame parsed successfully");
     return game;
 }
 
 
 static wstring fromUtf8(const string &str)
 {
-    return readFromUTF8(str.c_str(), str.size(), "Loading game");
+    return readFromUTF8(str, "Loading game");
 }
 
 
@@ -143,7 +157,6 @@ static Move buildMove(const Game &iGame, map<string, string> &attr,
 
 Game * XmlReader::getGame()
 {
-    // TODO
     return m_game;
 }
 
@@ -155,32 +168,19 @@ void XmlReader::startElement(const string& namespaceURI,
 {
     (void) namespaceURI;
     (void) qName;
-#if 0
-    if (!localName.empty())
-        std::cout << "Start Element: " << namespaceURI << ":" << localName << std::endl;
-    else
-        std::cout << "Start Element: " << qName << std::endl;
-#endif
+    LOG_DEBUG("Start Element: " << (localName.empty() ? qName : namespaceURI + ":" + localName));
+
     m_data.clear();
     const string &tag = localName;
     if (tag == "Player")
     {
         m_context = "Player";
-        m_attributes.clear();
         for (int i = 0; i < atts.getLength(); ++i)
         {
             m_attributes[atts.getLocalName(i)] = atts.getValue(i);
         }
     }
-    else if (tag == "PlayerRack")
-    {
-        m_attributes.clear();
-        for (int i = 0; i < atts.getLength(); ++i)
-        {
-            m_attributes[atts.getLocalName(i)] = atts.getValue(i);
-        }
-    }
-    else if (tag == "PlayerMove" || tag == "GameMove")
+    else if (tag == "PlayerRack" || tag == "PlayerMove" || tag == "GameMove")
     {
         m_attributes.clear();
         for (int i = 0; i < atts.getLength(); ++i)
@@ -196,38 +196,51 @@ void XmlReader::endElement(const string& namespaceURI,
                            const string&)
 {
     (void) namespaceURI;
-#if 0
-    std::cout << "endElement: " << namespaceURI << ":" << localName << "(" << m_data << ")" << std::endl;
-#endif
+    LOG_DEBUG("endElement: " << namespaceURI << ":" << localName << "(" << m_data << ")");
+
     const string &tag = localName;
     if (tag == "Mode")
     {
+        // The game should not be created yet
+        if (m_game != NULL)
+            throw LoadGameException("The 'Mode' tag should be the first one to be closed");
+
+        // Differ game creation until after we have read the variant
         if (m_data == "duplicate")
-            m_game = GameFactory::Instance()->createDuplicate(m_dic);
+            m_params.setMode(GameParams::kDUPLICATE);
         else if (m_data == "freegame")
-            m_game = GameFactory::Instance()->createFreeGame(m_dic);
+            m_params.setMode(GameParams::kFREEGAME);
         else if (m_data == "training")
-            m_game = GameFactory::Instance()->createTraining(m_dic);
+            m_params.setMode(GameParams::kTRAINING);
         else
-            throw LoadGameException("Invalid game mode: " + m_data);
+            throw GameException("Invalid game mode: " + m_data);
         return;
     }
 
-    // At this point, m_game must not be null anymore
-    if (m_game == NULL)
-        throw LoadGameException("The 'Mode' tag should be the first one to be closed");
-
     if (tag == "Variant")
     {
+        // The game should not be created yet
+        if (m_game != NULL)
+            throw LoadGameException("The 'Variant' tag should be right after the 'Mode' one");
+
         if (m_data == "bingo")
-            m_game->setVariant(Game::kJOKER);
+            m_params.addVariant(GameParams::kJOKER);
         else if (m_data == "explosive")
-            m_game->setVariant(Game::kEXPLOSIVE);
-        else
+            m_params.addVariant(GameParams::kEXPLOSIVE);
+        else if (m_data == "7among8")
+            m_params.addVariant(GameParams::k7AMONG8);
+        else if (m_data != "")
             throw LoadGameException("Invalid game variant: " + m_data);
+        return;
     }
 
-    else if (m_context == "Player")
+    // Create the game
+    if (m_game == NULL)
+    {
+        m_game = GameFactory::Instance()->createGame(m_params);
+    }
+
+    if (m_context == "Player")
     {
         if (tag == "Name")
             m_attributes["name"] = m_data;
@@ -276,16 +289,12 @@ void XmlReader::endElement(const string& namespaceURI,
             throw LoadGameException("Rack invalid for the current dictionary: " + m_data);
         }
         pldrack.setManual(rackStr);
-#if 0
-        cerr << "loaded rack: " << convertToMb(pldrack.toString()) << endl;
-#endif
+        LOG_DEBUG("loaded rack: " << lfw(pldrack.toString()));
 
         Player &p = getPlayer(m_players, m_attributes["playerid"]);
         PlayerRackCmd *cmd = new PlayerRackCmd(p, pldrack);
         m_game->accessNavigation().addAndExecute(cmd);
-#if 0
-        cerr << "rack: " << convertToMb(pldrack.toString()) << endl;
-#endif
+        LOG_DEBUG("rack: " << lfw(pldrack.toString()));
     }
 
     else if (tag == "PlayerMove")
@@ -310,15 +319,14 @@ void XmlReader::endElement(const string& namespaceURI,
 void XmlReader::characters(const string& ch)
 {
     m_data += ch;
-#if 0
-    std::cout << "Characters: " << ch << std::endl;
-#endif
+    LOG_DEBUG("Characters: " << ch);
 }
 
 
 void XmlReader::warning(const Arabica::SAX::SAXParseException<string>& exception)
 {
     errorMessage = string("warning: ") + exception.what();
+    LOG_WARN(errorMessage);
     //throw LoadGameException(string("warning: ") + exception.what());
 }
 
@@ -326,6 +334,7 @@ void XmlReader::warning(const Arabica::SAX::SAXParseException<string>& exception
 void XmlReader::error(const Arabica::SAX::SAXParseException<string>& exception)
 {
     errorMessage = string("error: ") + exception.what();
+    LOG_ERROR(errorMessage);
     //throw LoadGameException(string("error: ") + exception.what());
 }
 
@@ -333,6 +342,7 @@ void XmlReader::error(const Arabica::SAX::SAXParseException<string>& exception)
 void XmlReader::fatalError(const Arabica::SAX::SAXParseException<string>& exception)
 {
     errorMessage = string("fatal error: ") + exception.what();
+    LOG_FATAL(errorMessage);
     //throw LoadGameException(string("fatal error: ") + exception.what());
 }
 
