@@ -26,6 +26,7 @@
 #include "xml_writer.h"
 #include "encoding.h"
 #include "turn_cmd.h"
+#include "game_params.h"
 #include "game.h"
 #include "player.h"
 #include "ai_percent.h"
@@ -39,6 +40,7 @@
 
 using namespace std;
 
+INIT_LOGGER(game, XmlWriter);
 
 static void addIndent(string &s)
 {
@@ -76,11 +78,12 @@ static void writeMove(ostream &out, const Move &iMove,
     else if (iMove.getType() == Move::PASS)
         out << "pass\" />";
     else
-        throw SaveGameException("Unsupported move: " + convertToMb(iMove.toString()));
+        throw SaveGameException("Unsupported move: " + lfw(iMove.toString()));
 }
 
 void XmlWriter::write(const Game &iGame, const string &iFileName)
 {
+    LOG_INFO("Saving game into '" << iFileName << "'");
     ofstream out(iFileName.c_str());
     if (!out.is_open())
         throw SaveGameException("Cannot open file for writing: '" + iFileName + "'");
@@ -98,19 +101,21 @@ void XmlWriter::write(const Game &iGame, const string &iFileName)
     addIndent(indent);
     // Game type
     out << indent << "<Mode>";
-    if (iGame.getMode() == Game::kDUPLICATE)
+    if (iGame.getMode() == GameParams::kDUPLICATE)
         out << "duplicate";
-    else if (iGame.getMode() == Game::kFREEGAME)
+    else if (iGame.getMode() == GameParams::kFREEGAME)
         out << "freegame";
     else
         out << "training";
     out << "</Mode>" << endl;
 
     // Game variant
-    if (iGame.getVariant() == Game::kJOKER)
+    if (iGame.getParams().hasVariant(GameParams::kJOKER))
         out << indent << "<Variant>bingo</Variant>" << endl;
-    if (iGame.getVariant() == Game::kEXPLOSIVE)
+    if (iGame.getParams().hasVariant(GameParams::kEXPLOSIVE))
         out << indent << "<Variant>explosive</Variant>" << endl;
+    if (iGame.getParams().hasVariant(GameParams::k7AMONG8))
+        out << indent << "<Variant>7among8</Variant>" << endl;
 
     // Players
     for (unsigned int i = 0; i < iGame.getNPlayers(); ++i)
@@ -194,8 +199,9 @@ void XmlWriter::write(const Game &iGame, const string &iFileName)
             }
             else
             {
+                LOG_ERROR("Unsupported command: " << lfw(cmd->toString()));
                 // XXX
-                //throw SaveGameException("Unsupported command: " + convertToMb(cmd->toString()));
+                //throw SaveGameException("Unsupported command: " + lfw(cmd->toString()));
             }
             // TODO
         }
