@@ -23,9 +23,11 @@
 #include <QtGui/QMessageBox>
 #include <QtGui/QComboBox>
 #include <QtGui/QSpinBox>
+#include <QtCore/QSettings>
 
 #include "new_game.h"
 #include "qtcommon.h"
+#include "prefs_dialog.h"
 #include "game_factory.h"
 #include "game.h"
 #include "public_game.h"
@@ -46,6 +48,23 @@ NewGame::NewGame(QWidget *iParent)
     setupUi(this);
     lineEditName->setText(_q("Player %1").arg(2));
 
+    checkBoxJoker->setToolTip(_q(
+            "In a joker game, each rack contains a joker.\n"
+            "When a word containing the joker is played on the grid, the joker is then replaced\n"
+            "with the corresponding letter from the bag, and the joker stays in the rack.\n"
+            "When the corresponding letter is not present in the bag, the joker is placed on the board.\n"
+            "This variant, particularly interesting in Duplicate mode, is good to train using the joker."));
+    checkBoxExplosive->setToolTip(_q(
+            "An explosive game is a bit like a joker game, except that when the computer chooses the rack\n"
+            "(containing a joker), it performs a search and finds the best word possible with the rack.\n"
+            "Then, if possible, it replaces the joker in the rack with the letter allowing to play this best word.\n"
+            "This variant, unlike the joker game, allows playing with a normal-looking rack, but it usually gives\n"
+            "much higher scores than in a normal game."));
+    checkBox7Among8->setToolTip(_q(
+            "With this variant, the rack contains 8 letters instead of 7,\n"
+            "but at most 7 can be played at the same time.\n"
+            "This allows for more combinations during the game, and thus higher scores."));
+
     // Initialize the model of the default players
     m_model = new QStandardItemModel(2, 3, this);
     m_model->setHeaderData(0, Qt::Horizontal, _q("Name"), Qt::DisplayRole);
@@ -57,6 +76,9 @@ NewGame::NewGame(QWidget *iParent)
     m_model->setData(m_model->index(1, 1), _q(kAI));
     m_model->setData(m_model->index(1, 2), 100);
 
+    // Change the default AI level
+    refresh();
+
     // Initialize the QTreeView with the model we just created
     treeViewPlayers->setModel(m_model);
     PlayersTypeDelegate *typeDelegate = new PlayersTypeDelegate(this);
@@ -73,14 +95,24 @@ NewGame::NewGame(QWidget *iParent)
                      SIGNAL(selectionChanged(const QItemSelection&, const QItemSelection&)),
                      this,
                      SLOT(enableRemoveButton(const QItemSelection&, const QItemSelection&)));
-    // Enable the Ok button only when if there are enough players for the
+    // Enable the Ok button only if there are enough players for the
     // current mode
     QObject::connect(m_model, SIGNAL(rowsInserted(const QModelIndex&, int, int)),
                      this, SLOT(enableOkButton()));
     QObject::connect(m_model, SIGNAL(rowsRemoved(const QModelIndex&, int, int)),
                      this, SLOT(enableOkButton()));
-    QObject::connect(comboBoxMode, SIGNAL(currentIndexChanged(int)),
+    QObject::connect(radioButtonDuplicate, SIGNAL(toggled(bool)),
                      this, SLOT(enableOkButton()));
+    QObject::connect(radioButtonFreeGame, SIGNAL(toggled(bool)),
+                     this, SLOT(enableOkButton()));
+    QObject::connect(radioButtonTraining, SIGNAL(toggled(bool)),
+                     this, SLOT(enableOkButton()));
+    QObject::connect(radioButtonDuplicate, SIGNAL(toggled(bool)),
+                     this, SLOT(enablePlayers(bool)));
+    QObject::connect(radioButtonFreeGame, SIGNAL(toggled(bool)),
+                     this, SLOT(enablePlayers(bool)));
+    QObject::connect(radioButtonTraining, SIGNAL(toggled(bool)),
+                     this, SLOT(enablePlayers(bool)));
 
     // Install a custom event filter, to remove the selection when the
     // "Delete" key is pressed
@@ -91,20 +123,54 @@ NewGame::NewGame(QWidget *iParent)
 }
 
 
+void NewGame::refresh()
+{
+    // Retrieve the default computer level
+    QSettings qs(ORGANIZATION, PACKAGE_NAME);
+    int defLevel = qs.value(PrefsDialog::kINTF_DEFAULT_AI_LEVEL, 100).toInt();
+    // Ensure a valid range
+    if (defLevel < 0)
+        defLevel = 0;
+    if (defLevel > 100)
+        defLevel = 100;
+
+    // Update the level of the "Eliot" player only
+    for (int num = 0; num < m_model->rowCount(); ++num)
+    {
+        QString name = m_model->data(m_model->index(num, 0)).toString();
+        QString type = m_model->data(m_model->index(num, 1)).toString();
+        if (name == _q("Eliot") && type == _q(kAI))
+        {
+            m_model->setData(m_model->index(num, 2), defLevel);
+        }
+    }
+}
+
+
 PublicGame * NewGame::createGame(const Dictionary &iDic) const
 {
-    // Create the game
-    Game *tmpGame = NULL;
-    if (comboBoxMode->currentText() == _q("Training"))
-        tmpGame = GameFactory::Instance()->createTraining(iDic);
-    else if (comboBoxMode->currentText() == _q("Free game"))
-        tmpGame = GameFactory::Instance()->createFreeGame(iDic);
+    // Game parameters
+    GameParams params(iDic);
+    if (radioButtonTraining->isChecked())
+        params.setMode(GameParams::kTRAINING);
+    else if (radioButtonFreeGame->isChecked())
+        params.setMode(GameParams::kFREEGAME);
     else
-        tmpGame = GameFactory::Instance()->createDuplicate(iDic);
+        params.setMode(GameParams::kDUPLICATE);
+
+    if (checkBoxJoker->isChecked())
+        params.addVariant(GameParams::kJOKER);
+    if (checkBoxExplosive->isChecked())
+        params.addVariant(GameParams::kEXPLOSIVE);
+    if (checkBox7Among8->isChecked())
+        params.addVariant(GameParams::k7AMONG8);
+
+    // Create the game
+    Game *tmpGame = GameFactory::Instance()->createGame(params);
     PublicGame *game = new PublicGame(*tmpGame);
 
     // Add the players
-    if (comboBoxMode->currentText() != _q("Training"))
+    if (!radioButtonTraining->isChecked())
     {
         set<QString> allNames;
         for (int num = 0; num < m_model->rowCount(); ++num)
@@ -133,7 +199,7 @@ PublicGame * NewGame::createGame(const Dictionary &iDic) const
                 double level = m_model->data(m_model->index(num, 2)).toInt();
                 player = new AIPercent(level / 100.);
             }
-            player->setName(qtw(name));
+            player->setName(wfq(name));
             game->addPlayer(player);
         }
     }
@@ -142,12 +208,6 @@ PublicGame * NewGame::createGame(const Dictionary &iDic) const
         game->addPlayer(new HumanPlayer);
     }
 
-    // Joker game?
-    if (checkBoxJoker->isChecked())
-        game->setVariant(PublicGame::kJOKER);
-    if (checkBoxExplosive->isChecked())
-        game->setVariant(PublicGame::kEXPLOSIVE);
-
     return game;
 }
 
@@ -165,8 +225,8 @@ void NewGame::enableOkButton()
     // - if there is at least one player in duplicate mode
     // - if there are at least 2 players in free game mode
     bool disable =
-        (comboBoxMode->currentText() == _q("Duplicate") && m_model->rowCount() < 1) ||
-        (comboBoxMode->currentText() == _q("Free game") && m_model->rowCount() < 2);
+        (radioButtonDuplicate->isChecked() && m_model->rowCount() < 1) ||
+        (radioButtonFreeGame->isChecked() && m_model->rowCount() < 2);
     buttonBox->button(QDialogButtonBox::Ok)->setEnabled(!disable);
 }
 
@@ -180,9 +240,13 @@ void NewGame::enableRemoveButton(const QItemSelection &iSelected,
 }
 
 
-void NewGame::on_comboBoxMode_activated(int iIndex)
+void NewGame::enablePlayers(bool checked)
 {
-    groupBoxPlayers->setEnabled(iIndex != 2);
+    // Testing the "checked" variable prevents from doing the work twice
+    if (checked)
+    {
+        groupBoxPlayers->setEnabled(!radioButtonTraining->isChecked());
+    }
 }
 
 
