@@ -26,6 +26,8 @@
 
 #include <ui/prefs_dialog.ui.h>
 
+class QStringList;
+
 
 class PrefsDialog: public QDialog, private Ui::PrefsDialog
 {
@@ -36,10 +38,14 @@ public:
 
     static const QString kINTF_ALIGN_HISTORY;
     static const QString kINTF_DIC_PATH;
+    static const QString kINTF_DEFINITIONS_SITE_URL;
     static const QString kINTF_SHOW_TILES_POINTS;
     static const QString kINTF_WARN_REPLAY_TURN;
     static const QString kINTF_SHOW_TOOLBAR;
     static const QString kINTF_LINK_TRAINING_7P1;
+    static const QString kINTF_DEFAULT_AI_LEVEL;
+
+    static const QString kDEFAULT_DEF_SITE;
 
 public slots:
     /// Update the settings when the user selects "OK"
