@@ -1,8 +1,8 @@
 /*****************************************************************************
  * Eliot
- * Copyright (C) 2005-2009 Antoine Fraboulet & Olivier Teulire
+ * Copyright (C) 2005-2009 Antoine Fraboulet & Olivier Teulière
  * Authors: Antoine Fraboulet <antoine.fraboulet @@ free.fr>
- *          Olivier Teulire <ipkiss @@ gmail.com>
+ *          Olivier Teulière <ipkiss @@ gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -41,17 +41,18 @@
 #include "header.h"
 #include "dic_exception.h"
 #include "game_io.h"
+#include "game_params.h"
 #include "game_factory.h"
 #include "public_game.h"
-#include "training.h"
-#include "duplicate.h"
-#include "freegame.h"
+#include "game.h"
 #include "player.h"
 #include "ai_percent.h"
 #include "encoding.h"
 #include "game_exception.h"
 #include "settings.h"
 
+class Game;
+
 
 // Use a more friendly type name for the tokenizer
 typedef boost::tokenizer<boost::char_separator<wchar_t>,
@@ -178,7 +179,7 @@ wstring checkFileNameToken(const vector<wstring> &tokens, uint8_t index)
     const wstring &wstr = tokens[index];
     BOOST_FOREACH(wchar_t wch, wstr)
     {
-        if (!iswalpha(wch) && wch != L'.' && wch != L'_')
+        if (!iswalnum(wch) && wch != L'.' && wch != L'_')
             return L"";
     }
     return wstr;
@@ -198,6 +199,22 @@ wstring checkCrossToken(const vector<wstring> &tokens, uint8_t index)
     return wstr;
 }
 
+PublicGame * readGame(const Dictionary &iDic,
+                      GameParams::GameMode iMode, const wstring &iToken)
+{
+    GameParams params(iDic, iMode);
+    for (unsigned int i = 1; i < iToken.size(); ++i)
+    {
+        if (iToken[i] == L'j')
+            params.addVariant(GameParams::kJOKER);
+        else if (iToken[i] == L'e')
+            params.addVariant(GameParams::kEXPLOSIVE);
+        else if (iToken[i] == L'8')
+            params.addVariant(GameParams::k7AMONG8);
+    }
+    Game *tmpGame = GameFactory::Instance()->createGame(params);
+    return new PublicGame(*tmpGame);
+}
 
 void helpTraining()
 {
@@ -208,27 +225,27 @@ void helpTraining()
     printf("            gm -- grille + valeur des cases\n");
     printf("            gn -- grille + valeur des cases (variante)\n");
     printf("            gd -- grille + debug cross (debug only)\n");
-    printf("            l -- lettres non joues\n");
+    printf("            l -- lettres non jouées\n");
     printf("            p -- partie\n");
     printf("            pd -- partie (debug)\n");
     printf("            r -- recherche\n");
     printf("            s -- score\n");
     printf("            S -- score de tous les joueurs\n");
     printf("            t -- tirage\n");
-    printf("  d [] : vrifier le mot []\n");
-    printf("  b [b|p|r] [] : effectuer une recherche speciale  partir de []\n");
+    printf("  d [] : vérifier le mot []\n");
+    printf("  b [b|p|r] [] : effectuer une recherche speciale à partir de []\n");
     printf("            b -- benjamins\n");
     printf("            p -- 7 + 1\n");
     printf("            r -- raccords\n");
-    printf("  *    : tirage alatoire\n");
-    printf("  +    : tirage alatoire ajouts\n");
+    printf("  *    : tirage aléatoire\n");
+    printf("  +    : tirage aléatoire ajouts\n");
     printf("  t [] : changer le tirage\n");
-    printf("  j [] {} : jouer le mot [] aux coordonnes {}\n");
-    printf("  n [] : jouer le rsultat numro []\n");
-    printf("  r    : rechercher les meilleurs rsultats\n");
+    printf("  j [] {} : jouer le mot [] aux coordonnées {}\n");
+    printf("  n [] : jouer le résultat numéro []\n");
+    printf("  r    : rechercher les meilleurs résultats\n");
     printf("  s [] : sauver la partie en cours dans le fichier []\n");
     printf("  h [p|n|f|l|r] : naviguer dans l'historique (prev, next, first, last, replay\n");
-    printf("  q    : quitter le mode entranement\n");
+    printf("  q    : quitter le mode entraînement\n");
 }
 
 
@@ -241,14 +258,14 @@ void helpFreegame()
     printf("            gm -- grille + valeur des cases\n");
     printf("            gn -- grille + valeur des cases (variante)\n");
     printf("            j -- joueur courant\n");
-    printf("            l -- lettres non joues\n");
+    printf("            l -- lettres non jouées\n");
     printf("            p -- partie\n");
     printf("            s -- score\n");
     printf("            S -- score de tous les joueurs\n");
     printf("            t -- tirage\n");
     printf("            T -- tirage de tous les joueurs\n");
-    printf("  d [] : vrifier le mot []\n");
-    printf("  j [] {} : jouer le mot [] aux coordonnes {}\n");
+    printf("  d [] : vérifier le mot []\n");
+    printf("  j [] {} : jouer le mot [] aux coordonnées {}\n");
     printf("  p [] : passer son tour en changeant les lettres []\n");
     printf("  s [] : sauver la partie en cours dans le fichier []\n");
     printf("  h [p|n|f|l|r] : naviguer dans l'historique (prev, next, first, last, replay\n");
@@ -265,14 +282,14 @@ void helpDuplicate()
     printf("            gm -- grille + valeur des cases\n");
     printf("            gn -- grille + valeur des cases (variante)\n");
     printf("            j -- joueur courant\n");
-    printf("            l -- lettres non joues\n");
+    printf("            l -- lettres non jouées\n");
     printf("            p -- partie\n");
     printf("            s -- score\n");
     printf("            S -- score de tous les joueurs\n");
     printf("            t -- tirage\n");
-    printf("  d [] : vrifier le mot []\n");
-    printf("  j [] {} : jouer le mot [] aux coordonnes {}\n");
-    printf("  n [] : passer au joueur n[]\n");
+    printf("  d [] : vérifier le mot []\n");
+    printf("  j [] {} : jouer le mot [] aux coordonnées {}\n");
+    printf("  n [] : passer au joueur n°[]\n");
     printf("  s [] : sauver la partie en cours dans le fichier []\n");
     printf("  h [p|n|f|l|r] : naviguer dans l'historique (prev, next, first, last, replay\n");
     printf("  q    : quitter le mode duplicate\n");
@@ -282,28 +299,33 @@ void helpDuplicate()
 void help()
 {
     printf("  ?        : aide -- cette page\n");
-    printf("  e        : dmarrer le mode entranement\n");
-    printf("  ej       : dmarrer le mode entranement en partie joker\n");
-    printf("  ee       : dmarrer le mode entranement en partie dtonante\n");
-    printf("  d [] {}  : dmarrer une partie duplicate avec\n");
+    printf("  e        : démarrer le mode entraînement\n");
+    printf("  ej       : démarrer le mode entraînement en partie joker\n");
+    printf("  ee       : démarrer le mode entraînement en partie détonante\n");
+    printf("  e8       : démarrer le mode entraînement en partie 7 sur 8\n");
+    printf("  d [] {}  : démarrer une partie duplicate avec\n");
     printf("                [] joueurs humains et {} joueurs IA\n");
-    printf("  dj [] {} : dmarrer une partie duplicate avec\n");
+    printf("  dj [] {} : démarrer une partie duplicate avec\n");
     printf("                [] joueurs humains et {} joueurs IA (partie joker)\n");
-    printf("  de [] {} : dmarrer une partie duplicate avec\n");
-    printf("                [] joueurs humains et {} joueurs IA (partie dtonante)\n");
-    printf("  l [] {}  : dmarrer une partie libre avec\n");
+    printf("  de [] {} : démarrer une partie duplicate avec\n");
+    printf("                [] joueurs humains et {} joueurs IA (partie détonante)\n");
+    printf("  d8 [] {} : démarrer une partie duplicate avec\n");
+    printf("                [] joueurs humains et {} joueurs IA (partie 7 sur 8)\n");
+    printf("  l [] {}  : démarrer une partie libre avec\n");
     printf("                [] joueurs humains et {} joueurs IA\n");
-    printf("  lj [] {} : dmarrer une partie libre avec\n");
+    printf("  lj [] {} : démarrer une partie libre avec\n");
     printf("                [] joueurs humains et {} joueurs IA (partie joker)\n");
-    printf("  le [] {} : dmarrer une partie libre avec\n");
-    printf("                [] joueurs humains et {} joueurs IA (partie dtonante)\n");
+    printf("  le [] {} : démarrer une partie libre avec\n");
+    printf("                [] joueurs humains et {} joueurs IA (partie détonante)\n");
+    printf("  l8 [] {} : démarrer une partie libre avec\n");
+    printf("                [] joueurs humains et {} joueurs IA (partie 7 sur 8)\n");
     printf("  c []     : charger la partie du fichier []\n");
     printf("  x [] {1} {2} {3} : expressions rationnelles\n");
-    printf("          [] expression  rechercher\n");
-    printf("          {1} nombre de rsultats  afficher\n");
+    printf("          [] expression à rechercher\n");
+    printf("          {1} nombre de résultats à afficher\n");
     printf("          {2} longueur minimum d'un mot\n");
     printf("          {3} longueur maximum d'un mot\n");
-    printf("  s [b|i] {1} {2} : dfinir la valeur {2} pour l'option {1},\n");
+    printf("  s [b|i] {1} {2} : définir la valeur {2} pour l'option {1},\n");
     printf("                    qui est de type (b)ool ou (i)nt\n");
     printf("  q        : quitter\n");
 }
@@ -314,7 +336,7 @@ void displayData(const PublicGame &iGame, const vector<wstring> &tokens)
     const wstring &displayType = checkAlphaNumToken(tokens, 1);
     if (displayType == L"")
     {
-        cout << "commande incomplte\n";
+        cout << "commande incomplète\n";
         return;
     }
     if (displayType == L"g")
@@ -376,9 +398,9 @@ void commonCommands(PublicGame &iGame, const vector<wstring> &tokens)
         else
         {
             if (iGame.getDic().searchWord(word))
-                printf("le mot -%s- existe\n", convertToMb(word).c_str());
+                printf("le mot -%s- existe\n", lfw(word).c_str());
             else
-                printf("le mot -%s- n'existe pas\n", convertToMb(word).c_str());
+                printf("le mot -%s- n'existe pas\n", lfw(word).c_str());
         }
     }
     else if (tokens[0][0] == L'h')
@@ -421,7 +443,7 @@ void commonCommands(PublicGame &iGame, const vector<wstring> &tokens)
             }
             int res = iGame.play(word, coord);
             if (res != 0)
-                printf("Mot incorrect ou mal plac (%i)\n", res);
+                printf("Mot incorrect ou mal placé (%i)\n", res);
         }
     }
     else if (tokens[0][0] == L's')
@@ -431,7 +453,7 @@ void commonCommands(PublicGame &iGame, const vector<wstring> &tokens)
         {
             try
             {
-                iGame.save(convertToMb(word));
+                iGame.save(lfw(word));
             }
             catch (std::exception &e)
             {
@@ -447,8 +469,8 @@ void handleRegexp(const Dictionary& iDic, const vector<wstring> &tokens)
 {
     /*
     printf("  x [] {1} {2} {3} : expressions rationnelles\n");
-    printf("          [] expression  rechercher\n");
-    printf("          {1} nombre de rsultats  afficher\n");
+    printf("          [] expression à rechercher\n");
+    printf("          {1} nombre de résultats à afficher\n");
     printf("          {2} longueur minimum d'un mot\n");
     printf("          {3} longueur maximum d'un mot\n");
     */
@@ -477,7 +499,7 @@ void handleRegexp(const Dictionary& iDic, const vector<wstring> &tokens)
         return;
     }
 
-    printf("search for %s (%d,%d,%d)\n", convertToMb(regexp).c_str(),
+    printf("search for %s (%d,%d,%d)\n", lfw(regexp).c_str(),
            nres, lmin, lmax);
 
     vector<wdstring> wordList;
@@ -493,7 +515,7 @@ void handleRegexp(const Dictionary& iDic, const vector<wstring> &tokens)
 
     BOOST_FOREACH(const wdstring &wstr, wordList)
     {
-        printf("%s\n", convertToMb(wstr).c_str());
+        printf("%s\n", lfw(wstr).c_str());
     }
     printf("%lu printed results\n", (long unsigned)wordList.size());
 }
@@ -518,7 +540,7 @@ void setSetting(const vector<wstring> &tokens)
 
     try
     {
-        string setting = convertToMb(settingWide);
+        string setting = lfw(settingWide);
         if (type == L"i")
         {
             Settings::Instance().setInt(setting, wtoi(value.c_str()));
@@ -539,7 +561,7 @@ void setSetting(const vector<wstring> &tokens)
 
 void loopTraining(PublicGame &iGame)
 {
-    cout << "mode entranement" << endl;
+    cout << "mode entraînement" << endl;
     cout << "[?] pour l'aide" << endl;
 
     bool quit = 0;
@@ -596,7 +618,7 @@ void loopTraining(PublicGame &iGame)
                                             vector<wdstring> wordList;
                                             iGame.getDic().searchBenj(word, wordList);
                                             BOOST_FOREACH(const wdstring &wstr, wordList)
-                                                cout << convertToMb(wstr) << endl;
+                                                cout << lfw(wstr) << endl;
                                         }
                                         break;
                                     case L'p':
@@ -607,10 +629,10 @@ void loopTraining(PublicGame &iGame)
                                             for (it = wordMap.begin(); it != wordMap.end(); ++it)
                                             {
                                                 if (it->first != 0)
-                                                    cout << "+" << convertToMb(iGame.getDic().getHeader().getDisplayStr(it->first)) << endl;
+                                                    cout << "+" << lfw(iGame.getDic().getHeader().getDisplayStr(it->first)) << endl;
                                                 BOOST_FOREACH(const wdstring &wstr, it->second)
                                                 {
-                                                    cout << "  " << convertToMb(wstr) << endl;
+                                                    cout << "  " << lfw(wstr) << endl;
                                                 }
                                             }
                                         }
@@ -620,7 +642,7 @@ void loopTraining(PublicGame &iGame)
                                             vector<wdstring> wordList;
                                             iGame.getDic().searchRacc(word, wordList);
                                             BOOST_FOREACH(const wdstring &wstr, wordList)
-                                                cout << convertToMb(wstr) << endl;
+                                                cout << lfw(wstr) << endl;
                                         }
                                         break;
                                 }
@@ -674,7 +696,7 @@ void loopTraining(PublicGame &iGame)
             printf("%s\n", e.what());
         }
     }
-    printf("fin du mode entranement\n");
+    printf("fin du mode entraînement\n");
 }
 
 
@@ -800,7 +822,7 @@ void loopDuplicate(PublicGame &iGame)
                             int n = wtoi(id.c_str());
                             if (n < 0 || n >= (int)iGame.getNbPlayers())
                             {
-                                fprintf(stderr, "Numro de joueur invalide\n");
+                                fprintf(stderr, "Numéro de joueur invalide\n");
                                 break;
                             }
                             iGame.duplicateSetPlayer(n);
@@ -843,7 +865,7 @@ void mainLoop(const Dictionary &iDic)
 
         if (tokens.empty())
             continue;
-        if (tokens[0].size() > 2)
+        if (tokens[0].size() > 3)
         {
             printf("%s\n", "Invalid command");
             continue;
@@ -861,7 +883,7 @@ void mainLoop(const Dictionary &iDic)
                         const wstring &wfileName = checkFileNameToken(tokens, 1);
                         if (wfileName != L"")
                         {
-                            string filename = convertToMb(wfileName);
+                            string filename = lfw(wfileName);
                             try
                             {
                                 PublicGame *game = PublicGame::load(filename, iDic);
@@ -891,17 +913,8 @@ void mainLoop(const Dictionary &iDic)
                 case L'e':
                     {
                         // New training game
-                        Training *tmpGame = GameFactory::Instance()->createTraining(iDic);
-                        tmpGame->addPlayer(new HumanPlayer);
-                        PublicGame *game = new PublicGame(*tmpGame);
-                        // Set the variant
-                        if (tokens[0].size() > 1)
-                        {
-                            if (tokens[0][1] == L'j')
-                                game->setVariant(PublicGame::kJOKER);
-                            else if (tokens[0][1] == L'e')
-                                game->setVariant(PublicGame::kEXPLOSIVE);
-                        }
+                        PublicGame *game = readGame(iDic, GameParams::kTRAINING, tokens[0]);
+                        game->addPlayer(new HumanPlayer);
                         game->start();
                         loopTraining(*game);
                         //GameFactory::Instance()->releaseGame(*game);
@@ -923,20 +936,11 @@ void mainLoop(const Dictionary &iDic)
                             break;
                         }
                         // New duplicate game
-                        Duplicate *tmpGame = GameFactory::Instance()->createDuplicate(iDic);
-                        PublicGame *game = new PublicGame(*tmpGame);
+                        PublicGame *game = readGame(iDic, GameParams::kDUPLICATE, tokens[0]);
                         for (int i = 0; i < wtoi(nbHuman.c_str()); ++i)
                             game->addPlayer(new HumanPlayer);
                         for (int i = 0; i < wtoi(nbAI.c_str()); ++i)
                             game->addPlayer(new AIPercent(1));
-                        // Set the variant
-                        if (tokens[0].size() > 1)
-                        {
-                            if (tokens[0][1] == L'j')
-                                game->setVariant(PublicGame::kJOKER);
-                            else if (tokens[0][1] == L'e')
-                                game->setVariant(PublicGame::kEXPLOSIVE);
-                        }
                         game->start();
                         loopDuplicate(*game);
                         //GameFactory::Instance()->releaseGame(*game);
@@ -958,20 +962,11 @@ void mainLoop(const Dictionary &iDic)
                             break;
                         }
                         // New free game
-                        FreeGame *tmpGame = GameFactory::Instance()->createFreeGame(iDic);
-                        PublicGame *game = new PublicGame(*tmpGame);
+                        PublicGame *game = readGame(iDic, GameParams::kFREEGAME, tokens[0]);
                         for (int i = 0; i < wtoi(nbHuman.c_str()); i++)
                             game->addPlayer(new HumanPlayer);
                         for (int i = 0; i < wtoi(nbAI.c_str()); i++)
                             game->addPlayer(new AIPercent(1));
-                        // Set the variant
-                        if (tokens[0].size() > 1)
-                        {
-                            if (tokens[0][1] == L'j')
-                                game->setVariant(PublicGame::kJOKER);
-                            else if (tokens[0][1] == L'e')
-                                game->setVariant(PublicGame::kEXPLOSIVE);
-                        }
                         game->start();
                         loopFreegame(*game);
                         //GameFactory::Instance()->releaseGame(*game);
